@@ -6,11 +6,11 @@ Interchange6 - Open Source Shop Machine
 
 =head1 VERSION
 
-0.110
+0.120
 
 =cut
 
-our $VERSION = '0.110';
+our $VERSION = '0.120';
 
 =head1 DESCRIPTION
 
@@ -53,7 +53,7 @@ Please anticipate API changes in this early state of development.
 
 =head1 ACKNOWLEDGEMENTS
 
-Hunter McMillen, GH #31, #33.
+Hunter McMillen, GH #31, #33, #34.
 
 =head1 AUTHORS
 
